/*
 * Copyright 2006-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.objenesis.tck.features;

import java.util.ArrayList;
import java.util.List;

import org.objenesis.Objenesis;

/**
 * Base class for features. It provides recording of calls. The recording is static
 * to the class so we expect {@link Feature#isCompliant(Objenesis)} multiple implementations to be called in
 * the same thread.
 *
 * @author Henri Tremblay
 */
public abstract class AbstractFeature implements Feature {

   protected static final List<String> called = new ArrayList<>();

   public AbstractFeature() {
      called.clear();
   }
}
